2022/04/6 - RELEASE 1.0.5
==========================
Helper function:
- Adding a remove node function

Samples:
- Adding an additional sample to produce a valid UIM 3.1.0 vector file

2022/01/26 - RELEASE 1.0.4
==========================
Minor bug fix:
- WILL 2.0 File format files have been falsely identified as WILL data files.

2021/08/18 - RELEASE 1.0.2
==========================
First public release.